@@ -1,3 +1,4 @@
+import asyncio
 import urllib.parse
 from typing import List, Optional, Union
 
@@ -9,7 +10,7 @@ from dexguru_sdk.models.choices import *
 from dexguru_sdk.utils.get_query import get_query_from_params
 
 START_BLOCK_TIMESTAMP = 1588723228
-DEFAULT_DOMAIN = 'https://api.dev.dex.guru'
+DEFAULT_DOMAIN = 'https://api-public-stage.prod-euc1.dexguru.net'
 API_VERSION = 'v1/'
 
 
@@ -100,14 +101,11 @@ class DexGuru:
     async def search_tokens_by_name_or_symbol(
             self,
             chain_id: int,
-            name: str = None,
-            symbol: str = None,
+            search_string: str = None,
             limit: conint(gt=0, le=100) = 10,
             offset: conint(ge=0) = 0,
             verified: bool = True,
     ) -> models.TokensInventoryListModel:
-        if not name and not symbol:
-            raise ValueError('Specify name or symbol for search')
         query = get_query_from_params(**locals())
         response: dict = await self._client.get(f'{self._chain_prefix}/{chain_id}/tokens/?{query}')
         return models.TokensInventoryListModel.parse_obj(response)
@@ -127,7 +125,7 @@ class DexGuru:
         response: dict = await self._client.get(f'{self._chain_prefix}/{chain_id}/tokens/market/?{query}')
         return models.TokensFinanceListModel.parse_obj(response)
 
-    async def get_token_inventory(
+    async def get_token_inventory_by_address(
             self,
             chain_id: int,
             token_address: str,
@@ -401,3 +399,11 @@ class DexGuru:
     async def get_amm_inventory(self, chain_id: int, amm: AmmChoices) -> models.AmmModel:
         response: dict = await self._client.get(f'{self._chain_prefix}/{chain_id}/amms/{amm}')
         return models.AmmModel.parse_obj(response)
+
+if __name__ == '__main__':
+
+    sdk = DexGuru(api_key='23gttG8WmsS5EYrzNu3ayfRvqAT_JQMwmI3e8SNuCrg')
+
+    a = asyncio.run(sdk.search_tokens_by_name_or_symbol(1))
+    print(a)
+    pass
